---
name: "🐛 Bug report"
about: "Report a bug to help PIQA improve"
title: "[BUG] <issue> with <module.component>"
labels: bug
assignees: ''

---

### Description

A clear description of what the bug is.

### Reproduce

A minimal working example demonstrating the current behavior.

```python
from piqa import module
...
y = module.component(x)  # bug happens
```

### Expected behavior

A clear description of what you expected to happen.

### Causes and solution

If you know the causes and/or a solution to the bug, present them.

### Environment

* PIQA version: [e.g. 1.0.7]
* PyTorch version: [e.g. 1.8.0]
* Python version: [e.g. 3.6.4]
* OS: [e.g. Windows10]
